@@ -5,7 +5,7 @@ two2logthree <- function(x) {
   ans <- list()
   ans$mu  <- log(x$scale)+log(x$shape)/c
   ans$sigma <- ans$lambda <- 1/sqrt(x$shape)
-  ans$eta <- robustloggamma:::Exp.response(ans$mu,ans$sigma,ans$lambda)
+  ans$eta <- Exp.response(ans$mu,ans$sigma,ans$lambda)
  
   ans$muse  <- sqrt(avarmu(x$shape)) # you have to divide it by sqrt(n)
   ans$sigmase <- ans$lambdase <- sqrt(avarlambda(x$shape)) # you have to divide it by sqrt(n)
